@@ -7,9 +7,14 @@ test_that("tests for make_linelist", {
   msg <- "Must have at least 1 cols, but has 0 cols."
   expect_error(make_linelist(data.frame()), msg)
 
-  msg <- "Must be element of set \\{'speed','dist'\\}, but is 'bar'." # nolint
+  msg <- "Must be element of set \\{'speed','dist'\\}, but is" # nolint
   expect_error(make_linelist(cars, outcome = "bar"), msg)
 
+  expect_error(
+    make_linelist(cars, outcome = "bar", age = "bla"), 
+    "2 assertions failed"
+  )
+
   msg <- "Use only tags listed in `tags_names()`, or set `allow_extra = TRUE`"
   expect_error(
     make_linelist(cars, foo = "speed", allow_extra = FALSE),
@@ -32,9 +37,15 @@ test_that("tests for make_linelist", {
     c(tags_defaults(), foo = "speed", bar = "dist")
   )
 
-  x <- make_linelist(cars, date_onset = "dist", date_outcome = "speed")
-  y <- make_linelist(cars, list(date_onset = "dist", date_outcome = "speed"))
-  expect_identical(x, y)
+})
+
+test_that("make_linelist() works with dynamic dots", {
+
+  expect_identical(
+    make_linelist(cars, date_onset = "dist", date_outcome = "speed"),
+    make_linelist(cars, !!!list(date_onset = "dist", date_outcome = "speed"))
+  )
+
 })
 
 test_that("make_linelist() errors on data.table input", {
