@@ -1,9 +1,9 @@
 test_that("tests for tags_types", {
 
   # Check errors
-  msg <- "Unknown variable types: toto\n  Use only tags listed in `tags_names()`, or set `allow_extra = TRUE`"
+  msg <- "Use only tags listed in `tags_names()`, or set `allow_extra = TRUE`"
   expect_error(tags_types(toto = "ilestbo"), msg, fixed = TRUE)
-  
+
   # Check functionality
   x <- tags_types()
   expect_identical(tags_names(), names(x))
@@ -12,7 +12,6 @@ test_that("tests for tags_types", {
 
   x <- tags_types(date_outcome = "Date")
   expect_identical(x$date_outcome, "Date")
-  x <- tags_types(date_outcome = "Date", sequence = "DNAbin", allow_extra = TRUE)
-  expect_identical(x$sequence, "DNAbin")
-  
+  x <- tags_types(date_outcome = "Date", seq = "DNAbin", allow_extra = TRUE)
+  expect_identical(x$seq, "DNAbin")
 })
